@@ -274,7 +274,16 @@ class LocalPorvider(BaseProvider):
             fields: return
         """
         return TDP.get_daily_factorRet(instruments,fields,start_date,end_date)
-    
+
+    def daily_shsz_stkholding(self,instruments:list,fields:list,start_date:str,end_date:str):
+        """
+            table_name: 'CNE5S_100_DlyFacRet'
+            input: instruments,start_date,end_date
+            output: DataFrame
+            fields: return
+        """
+        return TDP.get_daily_shsz_stkholding(instruments,fields,start_date,end_date)
+
     def daily_indexweight(self,instruments,**kws):
         """
             table_name: 'AIndexFreeWeight'
@@ -500,6 +509,26 @@ class LocalPorvider(BaseProvider):
             fields : ...
         """
         return FRP.repo_issuedate_pre(instruments,fields,**kws)
+    
+    def frepo_qdii_secuportfolio(self,instruments,fields = None,**kws):
+        """
+            table_name: 'QDIISecuritiesPortfolio'
+            input:instruments:List(str),fields:List(str)
+                  optional: start_date:str,end_date:str,by [ann_date,reports_period]
+            output: DataFrame
+            fields : ...
+        """
+        return FuRP.frepo_qdii_secuportfolio(instruments,fields,**kws)
+    
+    def frepo_mufund_stkportfolio(self,instruments,fields = None,**kws):
+        """
+            table_name: 'ChinaMutualFundStockPortfolio'
+            input:instruments:List(str),fields:List(str)
+                  optional: start_date:str,end_date:str,by [ann_date,reports_period]
+            output: DataFrame
+            fields : ...
+        """
+        return FuRP.frepo_mufund_stkportfolio(instruments,fields,**kws)
 
     def consus(self,instruments,fields = None,foreward_type = 'fy1',window_days = '30d',**kws):
         """
@@ -542,5 +571,6 @@ IdxSP = getattr(status,provider_config["IdxSP"])()
 InstSP = getattr(status,provider_config["InstSP"])()
 InduSP = getattr(status,provider_config["InduSP"])()
 FRP = getattr(reports,provider_config["FRP"])()
+FuRP = getattr(reports,provider_config["FuRP"])()
 CDP = getattr(consus,provider_config["CDP"])()
 BP = eval(provider_config["BP"])()  
