@@ -32,6 +32,8 @@ aswsindexeod = os.path.join(data_path,r'ASWSIndexEOD')
 aindex_eod_price = os.path.join(data_path,r'AIndexEODPrices')
 aindex_idueodcitics = os.path.join(data_path,r'AIndexIndustriesEODCITICS')
 aindex_freeweight = os.path.join(data_path,r'AIndexFreeWeight')
+
+shszstockholding = os.path.join(data_path,r"SHSZstockhoding")
 #%%
 class BaseDailyTSInfoProvider(abc.ABC):
 
@@ -127,6 +129,10 @@ class TradeDayInfoProvider(BaseDailyTSInfoProvider):
     def get_daily_factorRet(self,instruments,fields,start_date,end_date):
         return self.get_daily_data(ashare_fact_ret,instruments,fields = fields ,start_date = start_date,end_date = end_date)
 
+    @print_func_time
+    def get_daily_shsz_stkholding(self,instruments,fields,start_date,end_date):
+        return self.get_daily_data(shszstockholding,instruments,fields = fields ,start_date = start_date,end_date = end_date)
+
     @print_func_time
     def get_daily_indexweight(self,instruments,**kws):
         df = self.get_sparse_daily_data(aindex_freeweight,instruments,**kws)
