@@ -20,6 +20,9 @@ ashare_holdernumber = os.path.join(data_path,r'AShareHolderNumber')
 ashare_issuedate_pre = os.path.join(data_path,r'AShareIssuingDatePredict')
 ashare_fanc_indicator = os.path.join(data_path,r'AShareFinancialIndicator')
 
+fund_qdii_secu_portfolio =  os.path.join(data_path,r"QDIISecuritiesPortfolio")
+fund_mu_fund_stkportfolio =  os.path.join(data_path,r"ChinaMutualFundStockPortfolio")
+
 class BaseFincReportsProvider(abc.ABC):
 
     @abc.abstractmethod
@@ -101,5 +104,46 @@ class LoacalFincReportsProvider(BaseFincReportsProvider):
     @print_func_time
     def repo_fanc_indicator(self,instruments,fields,**kws):
         return self.get_repo_data(ashare_fanc_indicator,instruments,fields,**kws)
-        
+
+class LoacalFundReportsProvider(BaseFincReportsProvider):
+
+
+    
+    def __init__(self, tidx=['prt_enddate','ann_date']) -> None:
+        self.tidx = tidx
+        super().__init__()
+
+    def get_repo_data(self,datapath,instruments,fields,**kws):
+        """ report table reader """
+        if isinstance(instruments,str):
+            instruments = [instruments]
+        path = os.path.join(datapath,'merged.h5')
+        data = read_mergeh5(path,instruments,fields,defualt_si,defualt_ei,self.tidx)
+        if data.empty:
+            return data
+        if ("start_date" in kws)&("end_date" in kws):
+            start_date,end_date = kws.get("start_date"),kws.get("end_date")
+            sd,ed = to_intdate(start_date),to_intdate(end_date)
+            if kws.get('by',None) == self.tidx[0]:
+                data = data.loc[(data[self.tidx[0]] >= sd) & (data[self.tidx[0]] <= ed)]
+            else:
+                try:
+                    data = data.loc[(data[self.tidx[1]]>=sd)&(data[self.tidx[1]]<=ed)]
+                except KeyError:
+                    data = data.loc[(data['ann_dt']>=sd)&(data['ann_dt']<=ed)] # 部分表用的 ann_dt
+
+        if self.tidx[0] in kws:
+            tgt_rp = kws.get(self.tidx[0],None)
+            if not isinstance(tgt_rp,Iterable):
+                tgt_rp = [tgt_rp,]
+            data = data.loc[data[self.tidx[0]].isin(tgt_rp)]
+        return data
+
+    @print_func_time
+    def frepo_qdii_secuportfolio(self,instruments,fields,**kws):
+        return self.get_repo_data(fund_qdii_secu_portfolio,instruments,fields,**kws) 
+
+    @print_func_time
+    def frepo_mufund_stkportfolio(self,instruments,fields,**kws):
+        return self.get_repo_data(fund_mu_fund_stkportfolio,instruments,fields,**kws)
 
